@@ -24,7 +24,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #ifndef __fifteenapplet_h__
 #define __fifteenapplet_h__
 
-#include <qttableview.h>
+#include "qttableview.h"
 #include <qmemarray.h>
 
 #include <kpanelapplet.h>
@@ -38,6 +38,7 @@ class PiecesTable : public QtTableView
 
 public:
     PiecesTable(QWidget* parent = 0, const char* name = 0);
+    QPopupMenu* popup() { return _menu; }
 
 protected:
     void resizeEvent(QResizeEvent*);
@@ -48,17 +49,18 @@ protected:
 
     void initMap();
     void initColors();
-    void randomizeMap();
     void checkwin();
 
+protected slots:
+    void randomizeMap();
+    void resetMap();
+
 private:
     QMemArray<int>    _map;
     QMemArray<QColor> _colors;
     QPopupMenu    *_menu;
     int _activeRow, _activeCol;
     bool            _randomized;
-
-    enum MenuOp { mRandomize = 1, mReset = 2 };
 };
 
 class FifteenApplet : public KPanelApplet
