@@ -79,8 +79,8 @@ SpritePixmapManager *SpritePixmapManager::manager()
 
 //===========================================================================
 //
-SpritePixmapSequence::SpritePixmapSequence(QList<QPixmap> pm, QList<QPoint> hs,
-        QArray<int> d)
+SpritePixmapSequence::SpritePixmapSequence(QPtrList<QPixmap> pm, QPtrList<QPoint> hs,
+        QMemArray<int> d)
     : QCanvasPixmapArray(pm, hs), mDelays(d)
 {
 }
@@ -137,13 +137,13 @@ SpritePixmapSequence *SpriteSequenceManager::read(KConfigBase &config)
 {
     QStrList strImages;
     QStrList strDelays;
-    QList<QPixmap> pixmaps;
-    QList<QPoint> hotspots;
+    QPtrList<QPixmap> pixmaps;
+    QPtrList<QPoint> hotspots;
 
     int frames = config.readListEntry("Images", strImages);
     config.readListEntry("Delays", strDelays);
 
-    QArray<int> delays(frames);
+    QMemArray<int> delays(frames);
 
     for (int i = 0; i < frames; i++)
     {
