@@ -31,6 +31,7 @@
 
 #include <qfile.h>
 #include <qtimer.h>
+#include <qpalette.h>
 
 #include "kweather.h"
 #include "reportview.h"
@@ -54,26 +55,27 @@ kweather::kweather(const QString& configFile, Type t, int actions,
         mFirstRun( false ), mReport( 0 ), mClient( 0 ),
         mContextMenu( 0 ), mWeatherService( 0 ), settingsDialog( 0 ), mTextColor(Qt::black)
 {
-	kdDebug(12004) << "Constructor " << endl;
-	setObjId("weatherIface");
-
-	loadPrefs();
-	initContextMenu();
-	initDCOP();
-
-	dockWidget = new dockwidget(reportLocation, this, "dockwidget");
-	connect(dockWidget, SIGNAL(buttonClicked()), SLOT(doReport()));
-	dockWidget->setViewMode(mViewMode);
-	dockWidget->setPaletteForegroundColor(mTextColor);
-
-	timeOut = new QTimer(this, "timeOut" );
-	connect(timeOut, SIGNAL(timeout()), SLOT(timeout()));
-	timeOut->start(10*60*1000);
-
-	if(mFirstRun)
-		preferences();
-	else
-		timeout();
+    kdDebug(12004) << "Constructor " << endl;
+    setObjId("weatherIface");
+    
+    setBackgroundOrigin( QWidget::AncestorOrigin );
+    loadPrefs();
+    initContextMenu();
+    initDCOP();
+    
+    dockWidget = new dockwidget(reportLocation, this, "dockwidget");
+    connect(dockWidget, SIGNAL(buttonClicked()), SLOT(doReport()));
+    dockWidget->setViewMode(mViewMode);
+    setLabelColor();
+    
+    timeOut = new QTimer(this, "timeOut" );
+    connect(timeOut, SIGNAL(timeout()), SLOT(timeout()));
+    timeOut->start(10*60*1000);
+    
+    if(mFirstRun)
+        preferences();
+    else
+        timeout();
 }
 
 kweather::~kweather()
@@ -98,27 +100,27 @@ void kweather::initContextMenu()
 
 void kweather::initDCOP()
 {
-	if ( !mClient )
-		mClient = KApplication::dcopClient();
-
-	if(!mClient->isAttached())
-		mClient->attach();
-
-	if(!attach())
-		return;
-
-	kdDebug(12004) << "attached to the server..." << endl;
-
-	if ( mWeatherService )
-		delete mWeatherService;
-
-	mWeatherService = new WeatherService_stub( "KWeatherService", "WeatherService" );
-
-	if (!connectDCOPSignal(0, 0, "fileUpdate(QString)",
-		"refresh(QString)",false))
-		kdDebug(12004) << "Could not attach dcop signal..." << endl;
-	else
-		kdDebug(12004) << "attached dcop signals..." << endl;
+    if ( !mClient )
+        mClient = KApplication::dcopClient();
+    
+    if(!mClient->isAttached())
+        mClient->attach();
+    
+    if(!attach())
+        return;
+    
+    kdDebug(12004) << "attached to the server..." << endl;
+    
+    if ( mWeatherService )
+        delete mWeatherService;
+    
+    mWeatherService = new WeatherService_stub( "KWeatherService", "WeatherService" );
+    
+    if (!connectDCOPSignal(0, 0, "fileUpdate(QString)",
+        "refresh(QString)",false))
+        kdDebug(12004) << "Could not attach dcop signal..." << endl;
+    else
+        kdDebug(12004) << "attached dcop signals..." << endl;
 }
 
 /** about box */
@@ -182,21 +184,21 @@ void kweather::doReport()
         return;
     }
 
-	kdDebug(12004) << "Showing out the report" << endl;
-	if ( mReport == 0 )
-	{
-		mReport = new reportView(reportLocation);
-
-		connect( mReport, SIGNAL( finished() ), SLOT( slotReportFinished() ) );
-	}
-
-	mReport->show();
-	mReport->raise();
+    kdDebug(12004) << "Showing out the report" << endl;
+    if ( mReport == 0 )
+    {
+        mReport = new reportView(reportLocation);
+    
+        connect( mReport, SIGNAL( finished() ), SLOT( slotReportFinished() ) );
+    }
+    
+    mReport->show();
+    mReport->raise();
 }
 
 void kweather::slotReportFinished(){
-	mReport->delayedDestruct();
-	mReport = 0;
+    mReport->delayedDestruct();
+    mReport = 0;
 }
 
 /** load the application */
@@ -220,15 +222,15 @@ void kweather::loadPrefs(){
 
 /** Save the application mPrefs. */
 void kweather::savePrefs(){
-	kdDebug(12004) << "Saving Prefs..." << endl;
-	KConfig *kcConfig = config();
-
-	kcConfig->setGroup("General Options");
-	kcConfig->writeEntry("logging", logOn);
-	kcConfig->writeEntry("report_location", reportLocation);
-	kcConfig->writeEntry("smallview_mode", mViewMode);
-	kcConfig->writePathEntry("log_file_name", fileName );
-	kcConfig->sync();
+    kdDebug(12004) << "Saving Prefs..." << endl;
+    KConfig *kcConfig = config();
+    
+    kcConfig->setGroup("General Options");
+    kcConfig->writeEntry("logging", logOn);
+    kcConfig->writeEntry("report_location", reportLocation);
+    kcConfig->writeEntry("smallview_mode", mViewMode);
+    kcConfig->writePathEntry("log_file_name", fileName );
+    kcConfig->sync();
 }
 
 void kweather::showWeather()
@@ -278,46 +280,46 @@ void kweather::writeLogEntry()
 }
 
 /** get new data */
-void kweather::timeout(){
-
-	if ( !mWeatherService )
-		initDCOP();
-
-	if ( mWeatherService )
-	{
-		// isEmtpy is true for null and 0 length strings
-		if ( !reportLocation.isEmpty() )
-		{
-			kdDebug(12004)<< "Requesting new data for " << reportLocation << endl;
-			mWeatherService->update(reportLocation);
-		}
-	}
+void kweather::timeout()
+{
+    if ( !mWeatherService )
+        initDCOP();
+    
+    if ( mWeatherService )
+    {
+        // isEmtpy is true for null and 0 length strings
+        if ( !reportLocation.isEmpty() )
+        {
+        kdDebug(12004)<< "Requesting new data for " << reportLocation << endl;
+        mWeatherService->update(reportLocation);
+        }
+    }
 }
 
 int kweather::widthForHeight(int h) const
 {
-	//kdDebug(12004) << "widthForHeight " << h << endl;
-	dockWidget->setOrientation(Horizontal);
-	int w = dockWidget->widthForHeight(h);
-	return w;
+    //kdDebug(12004) << "widthForHeight " << h << endl;
+    dockWidget->setOrientation(Horizontal);
+    int w = dockWidget->widthForHeight(h);
+    return w;
 }
 
 int kweather::heightForWidth(int w) const
 {
-	kdDebug(12004) << "heightForWidth " << w<< endl;
-	dockWidget->setOrientation(Vertical);
-	int h = dockWidget->heightForWidth( w );
-	return h;
+    kdDebug(12004) << "heightForWidth " << w<< endl;
+    dockWidget->setOrientation(Vertical);
+    int h = dockWidget->heightForWidth( w );
+    return h;
 }
 
 void kweather::refresh(QString stationID)
 {
-	kdDebug(12004) << "refresh " << stationID << endl;
-	if( stationID == reportLocation)
-	{
-		showWeather();
-		writeLogEntry();
-	}
+    kdDebug(12004) << "refresh " << stationID << endl;
+    if( stationID == reportLocation)
+    {
+        showWeather();
+        writeLogEntry();
+    }
 }
 
 void kweather::slotPrefsAccepted()
@@ -328,7 +330,7 @@ void kweather::slotPrefsAccepted()
 
     dockWidget->setLocationCode(reportLocation);
     dockWidget->setViewMode(mViewMode);
-    dockWidget->setPaletteForegroundColor(mTextColor);
+    setLabelColor();
     emit updateLayout();
 
     if (logOn && !fileName.isEmpty())
@@ -406,8 +408,18 @@ bool kweather::attach()
 
 void kweather::resizeEvent(QResizeEvent *e)
 {
-	kdDebug(12004) << "KWeather Resize event " << e->size() << endl;
-	dockWidget->resizeView(e->size());
+    kdDebug(12004) << "KWeather Resize event " << e->size() << endl;
+    dockWidget->resizeView(e->size());
+}
+
+void kweather::setLabelColor()
+{
+    setPaletteForegroundColor(mTextColor);
+}
+
+void kweather::paletteChange(const QPalette &)
+{
+    setLabelColor();
 }
 
 #include "kweather.moc"
