@@ -122,12 +122,16 @@ void reportView::render(){
     .arg(bgColor).arg(textColor).arg(textColor).arg(textColor).arg(textColor) +    
     QString("</style><title></title></head><body dir=\"%1\">").arg( QApplication::reverseLayout()?"rtl":"ltr") + 
     "<div class=\"headerTitle\"><b>" + i18n( "Weather Report - %1 - %2" ).arg( locationName ).arg( countryName ) +        
-    "</b></div>\n" +    
-    QString("<div class=\"headerMsg\"><b>" + i18n( "Last updated on %1" ) + "</b></div>\n"
-    "<table><tr><td width=\"60\" style=\"text-align: center; border: dotted %2 1px;\">"
-    "<img width=\"64\" height=\"64\" src=\"%3\" /></td>"
-    "<td style=\"vertical-align: top\">%4</td></tr>")
-    .arg(date).arg(bgColor).arg(KURL(icon).url()).arg(weatherText) +
+    "</b></div>\n";
+
+    if ( ! date.isEmpty() )
+      contents += "<div class=\"headerMsg\"><b>" + i18n( "Latest data from %1" ).arg(date) + "</b></div>\n";
+
+    contents += QString(
+    "<table><tr><td width=\"60\" style=\"text-align: center; border: dotted %1 1px;\">"
+    "<img width=\"64\" height=\"64\" src=\"%2\" /></td>"
+    "<td style=\"vertical-align: top\">%3</td></tr>")
+    .arg(bgColor).arg(KURL(icon).url()).arg(weatherText) +
     "</table><table>" +
     QString("<tr><th style=\"text-align: right\">" + i18n( "Temperature:" )
     + "</th><td>%1</td>"
