@@ -47,32 +47,45 @@ WeatherButton::WeatherButton( QWidget *parent, const char *name )
 
 void WeatherButton::drawButton( QPainter *p )
 {
-    if ( isDown() || isOn() )
-    {
-        p->setPen( Qt::black );
-        p->drawLine( 0, 0, width()-1, 0 );
-        p->drawLine( 0, 0, 0, height()-1 );
-        p->setPen( colorGroup().light() );
-        p->drawLine( 0, height()-1, width()-1, height()-1 );
-        p->drawLine( width()-1, 0, width()-1, height()-1 );
-    }
-
-    drawButtonLabel( p );
+    drawButtonLabel(p);
 }
 
 void WeatherButton::drawButtonLabel( QPainter *p )
 {
-    if ( pixmap() )
+    if (!pixmap())
     {
-        QPixmap pix = m_highlight? m_activeIcon : m_normalIcon;
-
-        if ( isOn() || isDown() )
-            p->translate( 2, 2 );
-
-        p->drawPixmap( pixmapOrigin(), pix );
+        return;
     }
+
+    QPixmap pix = m_highlight? m_activeIcon : m_normalIcon;
+
+    if (isOn() || isDown())
+    {
+        pix = pix.convertToImage().smoothScale(pix.width() - 2,
+                                               pix.height() - 2);
+    }
+
+    int h = height();
+    int w = width();
+    int ph = pix.height();
+    int pw = pix.width();
+    int margin = 3;
+    QPoint origin(margin / 2, margin / 2);
+
+    if (ph < (h - margin))
+    {
+        origin.setY((h - ph) / 2);
+    }
+
+    if (pw < (w - margin))
+    {
+        origin.setX((w - pw) / 2);
+    }
+
+    p->drawPixmap(origin, pix);
 }
 
+
 void WeatherButton::setPixmap( const QPixmap &pix )
 {
     QButton::setPixmap( pix );
