@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #include <kdebug.h>
@@ -73,7 +73,8 @@ void WeatherService::updateAll()
 {
 	kdDebug(12006) << "Sending for all" << endl;
 	QStringList stations =  m_weatherLib->stations();
-	for  ( QStringList::Iterator it = stations.begin(); it != stations.end(); ++it ) {
+	QStringList::ConstIterator end(stations.end());
+	for  ( QStringList::ConstIterator it = stations.begin(); it != end; ++it ) {
 		update(*it);
     	}
 
@@ -270,7 +271,7 @@ QString WeatherService::latitude(const QString &stationID)
 		return "None";
 }
 
-QStringList WeatherService::findStations(float lon, float lat)
+QStringList WeatherService::findStations(float /*lon*/, float /*lat*/)
 {
 	QStringList stationList;
 	stationList << "KMKE" << "KPNE" << "KTPW";
